#[non_exhaustive]pub enum DecimateError {
RaggedIndices(usize),
IndexOutOfRange(usize, u32),
InvalidBound(f64),
}Expand description
Why a decimation could not run.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RaggedIndices(usize)
The index buffer is not a whole number of triangles.
IndexOutOfRange(usize, u32)
A triangle references a vertex that does not exist.
InvalidBound(f64)
A deviation bound must be a positive, finite length.